@@ -1,6 +1,6 @@
 # ABSTRACT: Get information for different currencies
 package Data::MoneyCurrency;
-$Data::MoneyCurrency::VERSION = '0.18';
+$Data::MoneyCurrency::VERSION = '0.19';
 use strict;
 use warnings;
 use utf8;
@@ -9,7 +9,6 @@ require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(get_currency get_currencies_for_country);
 
-use File::ShareDir qw(dist_file);
 use Cpanel::JSON::XS;
 use Types::Serialiser;
 use Carp;
@@ -45,7 +44,7 @@ sub get_currency {
     }
 
     if (!defined($rh_currency_iso)) {
-        my $path = dist_file('Data-MoneyCurrency', 'currency_iso.json');
+        my $path = '../../ruby-money/config/currency_iso.json';
         open my $fh, "<:raw", $path or die $!;
         my $octet_contents = join "", readline($fh);
         close $fh or die $!;
@@ -281,7 +280,7 @@ my $rh_currencies_for_country = {
     sr   => ['srd'],
     ss   => ['ssp'],
     st   => ['std'],
-    sv   => ['usd'],
+    sv   => ['usd', 'btc'],
     sx   => ['ang'],
     sy   => ['syp'],
     sz   => ['szl'],
@@ -352,7 +351,7 @@ Data::MoneyCurrency - Get information for different currencies
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -370,7 +369,7 @@ Get currency information for different currencies.
     # }
 
 This uses some data found in the Ruby library
-L<money|https://github.com/RubyMoney/money/tree/master/config>, but it has no
+L<money|https://github.com/RubyMoney/money/tree/main/config>, but it has no
 dependency on it, the relevant data files are already included.
 
 =head1 EXPORT
